@@ -4,6 +4,12 @@ import core.models
 
 
 class EmailEndereco(core.models.Log):
+    """
+    :Nome da classe/função: EmailEndereco
+    :descrição: Classe de endereços de e-mail
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     email = models.EmailField(max_length=200, null=True)
     port = models.IntegerField(null=True)
     host = models.CharField(max_length=200, null=True)
@@ -13,8 +19,17 @@ class EmailEndereco(core.models.Log):
         abstract = False
         db_table = 'comunicacao_email_endereco'
 
+    def __str__(self):
+        return self.email
+
 
 class Email(core.models.Log):
+    """
+    :Nome da classe/função: Email
+    :descrição: Classe de e-mail
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=200, primary_key=True)
     nm_descritivo = models.CharField(max_length=200, null=True)
     assunto = models.CharField(max_length=200, null=True)
@@ -26,8 +41,17 @@ class Email(core.models.Log):
         abstract = False
         db_table = 'comunicacao_email'
 
+    def __str__(self):
+        return self.nm_descritivo
+
 
 class EmailLog(core.models.Log):
+    """
+    :Nome da classe/função: EmailLog
+    :descrição: Classe de log de e-mail
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     email = models.ForeignKey('Email', on_delete=models.DO_NOTHING, null=True)
     destinatario = models.CharField(max_length=200, null=True)
     retorno = models.TextField(null=True)
