@@ -5,6 +5,12 @@ import core.models
 
 # Create your models here.
 class Modulo(core.models.Log):
+    """
+    :Nome da classe/função: Modulo
+    :descrição: Classe de modulos de sistema
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.SlugField(max_length=100, primary_key=True)
     nm_descritivo = models.CharField(max_length=200, null=True)
     modulo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
@@ -15,6 +21,12 @@ class Modulo(core.models.Log):
 
 
 class Versao(core.models.Log):
+    """
+    :Nome da classe/função: Modulo
+    :descrição: Classe de versões do código para módulo
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     modulo = models.ForeignKey('sistema.Modulo', null=True, on_delete=models.DO_NOTHING)
     dat_atualizacao = models.DateField(null=True)
     codigo = models.CharField(max_length=100, null=True)
@@ -35,6 +47,12 @@ class Versao(core.models.Log):
 
 
 class VersaoItem(core.models.Log):
+    """
+    :Nome da classe/função: VersaoItem
+    :descrição: Classe de itens das versões
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     versao = models.ForeignKey('sistema.Versao', null=True, on_delete=models.DO_NOTHING)
     ordem = models.IntegerField(null=True)
     descricao = models.TextField(null=True)
@@ -53,6 +71,12 @@ class VersaoItem(core.models.Log):
 
 
 class PontoFuncao(core.models.Log):
+    """
+    :Nome da classe/função: PontoFuncao
+    :descrição: Classe de pontos de função do sistema
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     modulo = models.ForeignKey('sistema.Modulo', null=True, on_delete=models.DO_NOTHING)
     acao = models.CharField(max_length=100, primary_key=True)
     codigo = models.IntegerField(null=True)
@@ -68,6 +92,12 @@ class PontoFuncao(core.models.Log):
 
 
 class Perfil(core.models.Log):
+    """
+    :Nome da classe/função: Perfil
+    :descrição: Classe de perfil de acesso ao sistema que se relaciona com grupos de usuários e pontos de função
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nivel = models.IntegerField(null=True)
     is_login = models.BooleanField(null=True)
     is_staff = models.BooleanField(default=False)
@@ -84,6 +114,12 @@ class Perfil(core.models.Log):
 
 
 class PerfilPontoFuncao(core.models.Log):
+    """
+    :Nome da classe/função: PerfilPontoFuncao
+    :descrição: Classe de relação entre Perfil e Ponto Função
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     pontofuncao = models.ForeignKey('sistema.PontoFuncao', on_delete=models.DO_NOTHING, null=True)
     perfil = models.ForeignKey('sistema.Perfil', on_delete=models.DO_NOTHING, null=True)
 
@@ -93,6 +129,12 @@ class PerfilPontoFuncao(core.models.Log):
 
 
 class PerfilLogin(core.models.Log):
+    """
+    :Nome da classe/função: PerfilLogin
+    :descrição: Classe de relação entre o perfil, o módulo e qual a view inicial nesse sistema do usuário
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     modulo = models.ForeignKey('sistema.Modulo', null=True, on_delete=models.DO_NOTHING)
     perfil = models.ForeignKey('sistema.Perfil', on_delete=models.DO_NOTHING)
     view_inicial = models.CharField(max_length=200, null=True)
@@ -103,6 +145,12 @@ class PerfilLogin(core.models.Log):
 
 
 class PerfilGrupo(core.models.Log):
+    """
+    :Nome da classe/função: PerfilGrupo
+    :descrição: Classe de relação entre o perfil no sistema e grupo de usuário
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     perfil = models.ForeignKey('sistema.Perfil', on_delete=models.DO_NOTHING, null=True)
     grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)
 
